==> haskell-chunked-data-0.3.1-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-6akvIcgzifGForCYmwv0yi
key:                  chunked-data-0.3.1-6akvIcgzifGForCYmwv0yi
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  a08702392280a058d98214219a5783b2
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-8.10.2/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/chunked-data-0.3.1
hs-libraries:         HSchunked-data-0.3.1-6akvIcgzifGForCYmwv0yi
depends:
    base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    transformers-0.5.6.2 vector-0.12.1.2-KHX5U3TBRrFFuOQ5e4wn9L

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-8oXbT3tEFk7KWb32tDqHQk
key:                  chunked-data-0.3.1-8oXbT3tEFk7KWb32tDqHQk
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  1c30aca01bdfd70c18e4e8704dbd0782
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-8.10.2/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/chunked-data-0.3.1
hs-libraries:         HSchunked-data-0.3.1-8oXbT3tEFk7KWb32tDqHQk
depends:
    base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1 text-1.2.3.2
    transformers-0.5.6.2 vector-0.12.1.2-KGpjbWnxpe63faiPfNBnoV

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
